# stimpyp
utilities parser for the Stimpy module

## Installation

```bash
conda create -n stimpyp python=3.9 -y
conda activate stimpyp
pip install stimpyp
```

## See the [Documentation](https://stimpyp.readthedocs.io/en/latest/index.html) and [Example](https://github.com/ytsimon2004/stimpyp/blob/main/doc/source/notebooks/example_parsing.ipynb) 